//
//  BSInstallerApp.m
//  BSInspectorInstaller
//
//  Created by Karsten Kusche on 05.03.07.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#import "BSInstallerApp.h"


@implementation BSInstallerApp

- (void)initDispatchTable
{
	// that's a lot easier than a switch case thingy ;)
	
	dispatchTable = [[NSMutableDictionary dictionary] retain];
	[dispatchTable setObject:NSStringFromSelector(@selector(installXcodePlugin:)) forKey:@"xcplugin"];
	[dispatchTable setObject:NSStringFromSelector(@selector(installInspectorPlugin:)) forKey:@"bsInspector"];
	[dispatchTable setObject:NSStringFromSelector(@selector(installInspectorPlugin:)) forKey:@"bsDebugObject"];
	[dispatchTable setObject:NSStringFromSelector(@selector(installTemplate:)) forKey:@"xcTemplate"];
}

- (void)dealloc
{
	// needs to be released somehow
	
	[dispatchTable release];
	[super dealloc];
}

- (void)finishLaunching
{
	[super finishLaunching];
	[self setDelegate:self];
	[self initDispatchTable];
}

- (void)installFile:(NSString*)fileName
{
	// installes the supplied file, depending on its extension
	
	NSString* action = [dispatchTable objectForKey:[fileName pathExtension]];
	if (action)
	{
		[self performSelector:NSSelectorFromString(action) withObject:fileName];
	}
}

- (void)installFiles:(NSArray*)filenames
{
	NSEnumerator* files = [filenames objectEnumerator];
	NSString* file;
	while (file = [files nextObject])
	{
		[self installFile:file];
	}
}

- (void)application:(NSApplication *)sender openFiles:(NSArray *)filenames
{
	// install all supplied files
	
	[self installFiles:filenames];	
	[self terminate:nil];
}

- (BOOL)applicationShouldOpenUntitledFile:(NSApplication *)sender
{
	NSOpenPanel* op = [NSOpenPanel openPanel];
	[op setTitle:@"Choose a plugin to install"];
	[op setDirectory:[[[NSBundle mainBundle] bundlePath] stringByDeletingLastPathComponent]];
	[op setCanChooseFiles:YES];
	[op setAllowsMultipleSelection:YES];
	if ([op runModalForTypes:[dispatchTable allKeys]])
	{
		[self installFiles:[op filenames]];
	}
	[self terminate:nil];
	return NO;
}

- (BOOL)fileManager:(NSFileManager *)fm shouldProceedAfterError:(NSDictionary *)errorInfo
{
	// some error happend, report that to the user
	
	return NSRunAlertPanel(@"Error",@"Error happend when copying: %@.\nError: %@",@"Continue",@"Cancel",nil,[errorInfo objectForKey:@"Path"],[errorInfo objectForKey:@"Error"]) == NSOKButton;
}

- (void)fileManager:(NSFileManager *)fm willProcessPath:(NSString *)path
{
	// we're not logging the progress, so nothing done here
//	NSLog(@"going to process path: %@",[path description]);
}

int RunAlertPanelWithIcon(NSString* titel, NSString* message, NSString* but1, NSString* but2, NSString* but3, NSImage* icon, NSString* path)
{
	// our own RunAlertPanel implementation to use a different icon (the icon of the bundle that needs to be installed)
	
	NSAlert* alert = [NSAlert alertWithMessageText:titel defaultButton:but1 alternateButton:but2 otherButton:but3 informativeTextWithFormat:message,path];
	[alert setIcon:icon];
	return [alert runModal];
}

- (NSImage*)iconForFile:(NSString*)path
{
	// the icons are named like the extensions
	return [NSImage imageNamed:[path pathExtension]];
}

- (NSString*)getUserOrSystemLocationForPath:(NSString*)path
{
	// ask the user if the file should be installed in user or system space
	// return the appropreate library folder

	int res = RunAlertPanelWithIcon(@"Installation",
									@"Who should use the plugin: %@",
									@"Current user",
									@"All users",
									@"Cancel",
									[self iconForFile:path],
									[path lastPathComponent]);
	if (res == NSOKButton)
	{
		return [@"~/Library/" stringByExpandingTildeInPath];
	}
	else if (res == NSCancelButton)
	{
		return @"/Library/";
	}
	return nil;
}

- (NSString*)targetFolder: (NSString*)folder inDomain:(NSString*)domain
{
	// return the path like "domain/folder", but assert that folder exists
	
	NSString* result = domain;
	NSFileManager* fm = [NSFileManager defaultManager]; 
	NSArray* folderParts = [folder pathComponents];
	NSEnumerator* folders = [folderParts objectEnumerator];
	NSString* aPart;
	while (aPart = [folders nextObject])
	{
		result = [result stringByAppendingPathComponent:aPart];
		if (! [fm fileExistsAtPath:result])
		{
			[fm createDirectoryAtPath:result attributes:nil];
		}
	}
	return result;
}

- (void)copyFile: (NSString*)path toTargetFolder: (NSString*)targetSubFolder inDomain:(NSString*)targetDomain
{
	// copies the file from path to the subfolder after asking for the domain to install in
	if (targetDomain)
	{
		NSString* targetFolder = [self targetFolder:targetSubFolder inDomain:targetDomain]; 
		NSString* targetPath = [targetFolder stringByAppendingPathComponent:[path lastPathComponent]];
		if ([[NSFileManager defaultManager] fileExistsAtPath:targetPath])
		{
			NSWorkspace *ws = [NSWorkspace sharedWorkspace];
			
			if(![ws performFileOperation:NSWorkspaceRecycleOperation 
								  source:[targetPath stringByDeletingLastPathComponent] 
							 destination:@"" 
								   files:[NSArray arrayWithObject:[targetPath lastPathComponent]] 
									 tag:0])
			{
				NSLog(@"could not trash: %@",targetPath);
			}
			else
			{
//				NSLog(@"trashed: %@",targetPath);
			}
		}
		[[NSFileManager defaultManager] copyPath:path toPath:targetPath handler:self];
	}	
}

- (void)copyFile: (NSString*)path toTargetFolder: (NSString*)targetSubFolder
{
	NSString* targetDomain = [self getUserOrSystemLocationForPath:path];
	[self copyFile:path toTargetFolder:targetSubFolder inDomain: targetDomain];
}

- (void)installXcodePlugin:(NSString*)path
{
	// xcode plugins go to the dev-tools plugin folder
	[self copyFile: path toTargetFolder:@"/Application Support/Apple/Developer Tools/Plug-ins"];
}

- (void)installInspectorPlugin:(NSString*)path
{
	// bsinspector plugins go to the bsinspector folder
	[self copyFile: path toTargetFolder:@"/Application Support/BSInspectors"];
}
- (void)installTemplate:(NSString*)path
{
	// install the folder inside the template bundle to the project templates folder
	NSString* targetDomain = [self getUserOrSystemLocationForPath:path];
	
	[self copyFile: [path stringByAppendingPathComponent:@"/Custom Inspector/"] 
	toTargetFolder: @"/Application Support/Apple/Developer Tools/Project Templates/Bundle"
		  inDomain: targetDomain];
}
@end
