#import "BSArrayInspector.h"
#import "BSArrayDebugObject.h"
#import "GDB_AdapterExtension.h"

@implementation BSArrayDebugObject (InspectorClassName)

+ (Class)inspectorClass
{
	// BSArrayDebugObjects are inspected by BSArrayInspectors
	return [BSArrayInspector class];
}

@end



@implementation BSArrayInspector

- (NSString*)nibName
{
	// the array inspector window is stored in the ArrayInspector.nib
	return @"ArrayInspector";
}

- (void)awakeFromNib
{
	// after initializing the text-inspector, also init the array inspector list
	[super awakeFromNib];
	[arrayInspector setDataSource:self];
	[arrayInspector setDelegate:self];
	[arrayInspector setDoubleAction:@selector(doubleClickAction:)];
}

- (void)setStringValue
{
	// select the first item in the list
	if ([[debugObject targetObject] count])
	{
		[arrayInspector selectRow:0 byExtendingSelection:NO];
	}
}

- (int)numberOfRowsInTableView:(NSTableView *)tableView
{
	// we're showing the array in this view, so the number of rows is the number of items in the array
	return [[debugObject targetObject] count];
}

- (id)tableView:(NSTableView *)tableView objectValueForTableColumn:(NSTableColumn *)tableColumn row:(int)row
{
	// show the short-description in the list of objects
	return [[[debugObject targetObject] objectAtIndex:row] shortDescription];
}

- (id)selectedObject
{
	if ([arrayInspector selectedRow] < 0) return nil;
	// returns the selected debug-object
	return [[debugObject targetObject] objectAtIndex:[arrayInspector selectedRow]];
}

- (void)tableViewSelectionIsChanging:(NSNotification*)notif
{
	// when the selection changed, show the selected debug object in the text-inspector
	[textInspector setString:[[self selectedObject] description]];
}

- (void)doubleClickAction:(id)sender
{
	// if an item got double-clicked, spawn that object in a new inspector
	NSMutableData *data = [NSMutableData data];
	NSKeyedArchiver* archiver = [[NSKeyedArchiver alloc] initForWritingWithMutableData:data]; 
	[archiver encodeObject:[self selectedObject] forKey:@"debugObject"];
	[archiver finishEncoding];
	[BSInspector inspectData:data];
}
@end  
