//
//  BSDebugObject.m
//  XcodeInspectors
//
//  Created by Karsten Kusche on 23.02.07.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#import "BSDebugObject.h"
#import "NSObjectExt.h"

@implementation BSDebugObject

+ (id)debugObjectWith:(id)object
{
	// initialize a new debug object with the supplied object.
	// choose the debug object class from the objects settings (objects return BSDebugObject while arrays return BSArrayDebugObject)
	id new = [[object debuggerObjectClass] alloc];
	if ([new initWithObject:object])
	{
		return new;
	}
	[new release];
	return nil;
}

- (id)initWithObject:(id)object
{
	if (self = [super init])
	{
		targetObject = [object retain];
		longDescription = nil;
		shortDescription = nil;
		objectPointer = [[NSNumber numberWithUnsignedInt:(unsigned int)targetObject] retain];
	}
	return self;
}

- (NSString*)description
{
	// the description of the debug object is the target apps description
	if (longDescription == nil)
	{
		longDescription = [[NSString stringWithString:[[self targetObject] description]] retain];
	}
	return longDescription;
}

- (NSString*)shortDescription
{
	// same as description, but for the short thing
	if (shortDescription == nil)
	{
		shortDescription = [[NSString stringWithString:[[self targetObject] shortDescription]] retain];
	}
	return shortDescription;
}

- (id)targetObject
{
	if (targetObject)
		return targetObject;
	return [self description];
}

- (id)initWithCoder:(NSCoder*)decoder
{
	if (self = [super init])
	{
		objectPointer = [[decoder decodeObjectForKey:@"objectPointer"] retain];
		longDescription = [[decoder decodeObjectForKey:@"longDescription"] retain];
		shortDescription = [[decoder decodeObjectForKey:@"shortDescription"] retain];
		targetObject = nil; // target object is not encoded in the BSDebugObject
	}
	return self;
}

- (NSNumber*)objectPointer
{
	// returns a number containing the target objects pointer
	if (objectPointer) return objectPointer;
	return objectPointer = [[NSNumber numberWithUnsignedInt:(unsigned int)targetObject] retain];
}

- (void)_encodeWithCoder:(NSCoder*)encoder
{
	// do nothing, used in subclasses
}

- (void)encodeWithCoder:(NSCoder*)encoder
{
	[encoder encodeObject:[self objectPointer] forKey:@"objectPointer"];
	[encoder encodeObject:[self shortDescription] forKey:@"shortDescription"];
	[encoder encodeObject:[self description] forKey:@"longDescription"];
	[self _encodeWithCoder:encoder]; // this can be used by subclasses to encode their data
}

@end
