#import "BSDictionaryInspector.h"
#import "BSDictionaryDebugObject.h"

@implementation BSDictionaryDebugObject (InspectorClassName)

+ (Class)inspectorClass
{
	// BSDictionaryDebugObjects are inspected by a BSDictionaryInspector
	return [BSDictionaryInspector class];
}

@end



@implementation BSDictionaryInspector

- (NSString*)nibName
{
	// the inspector's window is stored in DictionaryInspector
	return @"DictionaryInspector";
}

- (NSArray*)keys
{
	// returns allkeys of the dictionary in targetObject
	NSDictionary* dict = [debugObject targetObject];
	return [dict allKeys];
}

- (int)numberOfRowsInTableView:(NSTableView *)tableView
{
	// the table shows the keys
	return [[self keys] count];
}

- (id)tableView:(NSTableView *)tableView objectValueForTableColumn:(NSTableColumn *)tableColumn row:(int)row
{
	// the strings shown in the list are the short-description of the objects
	return [[[self keys] objectAtIndex:row] shortDescription];
}

- (id)selectedObject
{
	if ([arrayInspector selectedRow] < 0) return nil;
	// the selected object is either the key or the value of the selected object at the selected row
	NSString* selectedKey = [[self keys] objectAtIndex:[arrayInspector selectedRow]];
	if ([keyOrValue intValue] == 1) // keys is selected
	{
		return [BSDebugObject debugObjectWith:selectedKey];
	}
	else // values is selected
	{
		return [[debugObject targetObject] objectForKey:selectedKey];
	}
	
}

- (void)tableViewSelectionDidChange:(NSNotification*)notif
{	
	// if the selection changed, show the selected object in the text-inspector
	[textInspector setString:[[self selectedObject] description]];
}

@end
