//
//  BSInspector.m
//  XcodeInspectors
//
//  Created by Karsten Kusche on 18.02.07.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#import "BSInspector.h"
#import "BSArrayInspector.h"
#import "BSDictionaryInspector.h"

@implementation BSDebugObject (InspectorClassName)
// this class extension tells the debug objects which inspector will show them. 
// by default this is done by BSInspector.

+ (Class)inspectorClass
{
	// normal debug objects are inspected by the standard-inspector
	return [BSInspector class];
}

- (Class)inspectorClass
{
	// objects ask their class for the inspector-class, same as with the debug-object class
	return [[self class] inspectorClass];
}

@end


@implementation BSInspector

- (NSString*)nibName
{
	// the name of the nib-file this inspector is using
	
	// reimplement this in sub-classes
	return @"StandardInspector";
}

- (void)loadNib
{
	// load the nib-file that this inspector will use to display the data
	[NSBundle loadNibNamed:[self nibName] owner:self];
}

- (id)initWithDebugObject:(BSDebugObject*)aDebugObject
{
	// initialize the inspector by setting the debug object and load the nib
	if (self = [super init])
	{	
		debugObject = aDebugObject;
		[self loadNib];
	}
	return self;
}

+ (void)inspectData:(NSData*)data 
{
	// this will decode the data and create a inspector based on the decoded object
	if (data == nil)
	{
		return;
	}
	Class class;
	NSKeyedUnarchiver* unarchiver = [[NSKeyedUnarchiver alloc] initForReadingWithData:data];
	id debugObject = [[unarchiver decodeObjectForKey:@"debugObject"] retain];
	[unarchiver finishDecoding];
	[unarchiver release];
	
	// this will query the inspector class from the debug object. 
	// the default is the current class, but custom debug objects may have custom inspectors
	class = [debugObject inspectorClass];
	
	[[class alloc] initWithDebugObject: debugObject];
}

- (void)setStringValue
{
	// sets the textinspector's string value
	[textInspector setString:[debugObject description]];
}

- (void)awakeFromNib
{
	// open the window, set its delegate and set the string value
	[inspectorWindow makeKeyAndOrderFront:nil];
	[inspectorWindow setDelegate:self];
	[self setStringValue];
}

- (void)dealloc
{
	[debugObject release];
	[super dealloc];
}

@end
