//
//  BSPluginLoader.m
//  XcodeInspectors
//
//  Created by Karsten Kusche on 17.02.07.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#import "BSPluginLoader.h"
#import "DebuggerHook.h"

#import </usr/include/objc/objc-class.h>


void MethodSwizzle(Class aClass, SEL orig_sel, SEL alt_sel)
{
    Method orig_method = nil, alt_method = nil;
	
    // First, look for the methods
    orig_method = class_getInstanceMethod(aClass, orig_sel);
    alt_method = class_getInstanceMethod(aClass, alt_sel);
	
    // If both are found, swizzle them
    if ((orig_method != nil) && (alt_method != nil))
	{
        char *temp1;
        IMP temp2;
		
        temp1 = orig_method->method_types;
        orig_method->method_types = alt_method->method_types;
        alt_method->method_types = temp1;
		
        temp2 = orig_method->method_imp;
        orig_method->method_imp = alt_method->method_imp;
        alt_method->method_imp = temp2;
//		NSLog(@"methods swizzled");
	}
	else
	{
		NSLog(@"could not swizzle methods!");
	}
}


@implementation BSPluginLoader

+ (int)loadPluginsAtPath:aPath
{
	// loads all inspector plugins at the given path
	int bundleCount = 0;
	NSArray* pluginFiles = [[NSFileManager defaultManager] directoryContentsAtPath:aPath];
	if (pluginFiles == nil) return 0; // folder doesn't exist
	NSEnumerator* plugins = [pluginFiles objectEnumerator];
	NSString* plugin;
	while (plugin = [plugins nextObject])
	{
		if ([[plugin pathExtension] isEqual:@"bsInspector"] || [[plugin pathExtension] isEqual:@"bsDebugObject"])
		{
			// principalClass returns the bundles principal class and loads the bundle if it's not loaded already
			Class bundleClass = [[NSBundle bundleWithPath:[aPath stringByAppendingPathComponent:plugin]] principalClass];
			if (bundleClass)
			{
				bundleCount ++;
//				NSLog(@"loaded inspector-bundle: %@",[aPath stringByAppendingPathComponent:plugin]);
			}
		}
	}
	return bundleCount;
}

+ (void)pluginDidLoad:(id)sender
{
	// swizzles the methods so that the inspectors are opened instead of the expression viewer
	// and then loads all the inspector plugins that are installed
	MethodSwizzle([PBXDebugStackFrameViewModule class], @selector(debugDataMenuCloneVariableByExpression:), @selector(inspectValue:));
	
	NSArray* pluginFolders = [NSArray arrayWithObjects:@"~/Library/Application Support/BSInspectors",@"/Library/Application Support/BSInspectors",nil];
	NSEnumerator* folders = [pluginFolders objectEnumerator];
	NSString* aPath;
	int bundleCount = 0;
	while (aPath = [folders nextObject])
	{
		bundleCount += [self loadPluginsAtPath:[aPath stringByExpandingTildeInPath]];
	}
	NSLog(@"BSInspector Plugin loaded with: %i plugins", bundleCount);
}

@end
