//
//  BS_CallForDebugDataSequence.m
//  XcodeInspectors
//
//  Created by Karsten Kusche on 28.02.07.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#import "BS_CallForDebugDataSequence.h"
#import "BS_MICallForDebugDataCommand.h"
#import "GDB_AdapterExtension.h"
#import "NSObjectExt.h"
#import "BSInspector.h"
#import <mach/mach.h>

@implementation BS_CallForDebugDataSequence

- (id)initWithValue:(NSString*)pointer
{
	// this sequence will request and load the data from the target app
	if (self = [super init])
	{
		// first command is to call for the debug object
		_miCommand = [[BS_MICallForDebugDataCommand miCommand] retain];
		[_miCommand setTarget:self];
		[_miCommand setFinishAction:@selector(finishedCall:)];
		[(BS_MICallForDebugDataCommand*)_miCommand setObjectPointer:pointer];
	}
	return self;
}

- (BOOL)handleErrorForMICommand:(id)command
{
	if ([command isKindOfClass:[BS_MICallForDebugDataCommand class]])
	{
		// the debug-extension is not yet loaded..
		NSRunAlertPanel(@"Error",@"Debug Extension has not yet been loaded",@"Ok",nil,nil);
	}
	return YES;
}

- (void)execute
{
	// when executed, it will post the command to create the debug data
	[[[self gdbAdaptor] miController] postCommand:_miCommand];
}

- (void)finishedCall:(BS_MICallForDebugDataCommand*)command
{
	// once the data-creation command has been completed, the next command is posted to read the size and the pointer of the debug data
	if ([[[command parseResults] itemWithKey:@"value"] value])
	{	
		[_miCommand release];
		_miCommand = [[PBXGDB_MIReadMemoryCommand miCommand] retain];
		[_miCommand setTarget:self];
		[_miCommand setFinishAction:@selector(gotData:)];
		[(PBXGDB_MIReadMemoryCommand*)_miCommand setBaseAddressString:[[[command parseResults] itemWithKey:@"value"] value] format:1 bytesPerWord:4 rows:2 wordsPerRow:1];
		
		[[[self gdbAdaptor] miController] postCommand:_miCommand];
	}
	else
	{
		NSLog(@"no debug object...input manager may not be loaded");
	}
}

- (void)gotData:(PBXGDB_MIReadMemoryCommand*)something
{
	// if the debug data location and size have been finished, the debug data itself is requested with the next call
//	NSLog(@"got data...");
	char gotSomething;
	int i = 0;
	NSMutableData* data = [NSMutableData data];
	do
	{
		[data appendData:[something rowValuesAsDataResultStatus:&gotSomething]];
	} while ([something nextRow] && i++ < 10);
	BSDebugDataStructure ds;
	[data getBytes:&(ds.size) range:NSMakeRange(0,4)];
	[data getBytes:&(ds.data) range:NSMakeRange(4,4)];
	
//	NSLog(@"struct: size = %i, data at: %p",ds.size,ds.data);
	
	// the following _miCommand stuff is SLOW...really it's not suitable for kilobytes of data at all, but it's working.

	[_miCommand release];
	_miCommand = [[PBXGDB_MIReadMemoryCommand miCommand] retain];
	[_miCommand setTarget:self];
	[_miCommand setFinishAction:@selector(gotDebugData:)];

	// using 1 byte per words is SO SLOW, but thanks to little endian chips it's needed to get the bytes over in the correct order
	[(PBXGDB_MIReadMemoryCommand*)_miCommand setBaseAddressString:[NSString stringWithFormat:@"%p",ds.data] format:1 bytesPerWord:1 rows:1 wordsPerRow:ds.size];	

/*	
	// the following code does not work on intel macs, because apple restricts the use of taks_for_pid.
	// however, this would speedup getting the debug data from the target app a lot...mabye someone finds a solution
 
    int pid = [[[self gdbAdaptor] gdbTask] processID];
	mach_port_t port;
	unsigned char* bufferAddress = (unsigned char*)malloc(ds.size);
	kern_return_t err;
	if (err = task_for_pid(mach_task_self(),pid,&port))
	{
		NSLog(@"[-]error creating port: 0x%x\n",err);
		[self didFinish];
		return;
	}
	
	unsigned int sizeRead = ds.size;
	
	if (err = vm_read_overwrite(port, (vm_address_t)ds.data , ds.size , (vm_address_t)bufferAddress, &sizeRead))
	{
		NSLog(@"error: %i, only read 0x%x bytes\n",err,sizeRead);
		[self didFinish];
		return;
	}
	NSData* remoteData = [NSData dataWithBytes:bufferAddress length:ds.size];
	[BSInspector inspectData:remoteData];
//*/
	[[[self gdbAdaptor] miController] postCommand:_miCommand];
}

- (void)gotDebugData:(PBXGDB_MIReadMemoryCommand*)something
{
	// once the debug data has been received, the inspector is opened with this data
//	NSLog(@"got debugData...");
	char gotSomething;
	int i = 0;
	NSMutableData* data = [NSMutableData data];
	do
	{
		[data appendData:[something rowValuesAsDataResultStatus:&gotSomething]];
	} while ([something nextRow] && i++ < 10);

//	NSLog(@"data = %@",[data description]);
	
	[BSInspector inspectData:data];
	[self didFinish];
}

- (void)didFinish
{
	// sequence is finished
	[super didFinish];
//	NSLog(@"finished this sequence...");
}

- (void)dealloc
{
	[_miCommand release];
	[super dealloc];
}
@end
