//
//  BS_LoadDebugExtensionSequence.m
//  XcodeInspectors
//
//  Created by Karsten Kusche on 05.03.07.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#import "BS_LoadDebugExtensionSequence.h"
#import "gdbplugin.h"
#import "BS_MICreateOFICommand.h"
#import "BS_MIAllocateOFIBufferCommand.h"
#import "BS_MILinkModuleCommand.h"
#import "BS_MICheckForDebugExtensionCommand.h"

@implementation BS_LoadDebugExtensionSequence

- (id)init
{
	// init with the first command, which checks if the debug extension is loaded.
	if (self = [super init])
	{
		_miCommand = [[BS_MICheckForDebugExtensionCommand miCommand] retain];
		[_miCommand setTarget:self];
		[_miCommand setFinishAction:@selector(checkForDebugExtension:)];
		[(BS_MICheckForDebugExtensionCommand*)_miCommand setCommand];		
	}
	return self;	
}

- (void)execute
{
	// executing is simply to post the command to the controller
	
 	[[[self gdbAdaptor] miController] postCommand:_miCommand];
}

- (void)checkForDebugExtension:(id)command
{
	// the debeg extension my be present or not. if it is, finish this sequence and if not, load the debug extension
//	NSLog(@"checkForExtension: %@ <##> %@",[command GDBCommandString],[[command parseResults] description]);	
	NSString* result = [[[command parseResults] itemWithKey:@"value"] value];
	if ([result isEqual:@"0"])
	{
		[_miCommand release];
		_miCommand = [[BS_MIAllocateOFIBufferCommand miCommand] retain];
		[_miCommand setTarget:self];
		[_miCommand setFinishAction:@selector(bufferCreated:)];
		[(BS_MIAllocateOFIBufferCommand*)_miCommand setCommand];
		
		[[[self gdbAdaptor] miController] postCommand:_miCommand];		
	}	
	else
	{
//		NSLog(@"DebugExtension already present");
		[self didFinish];
	}
}

- (NSBundle*)debugExtensionBundle
{
	// returns the bundle of the debug extension.
	// this extension is located in the resource-folder of this xcode plugin
	
	NSBundle* bundle = [NSBundle bundleForClass:[self class]];
	NSString* path = [bundle pathForResource:@"DebugExtensions" ofType:@"bundle"];
	return [NSBundle bundleWithPath:path];
}

- (void)bufferCreated:(id)command
{
	// the buffer for the OFI is created, init the ofi

	//	NSLog(@"buffer created: %@ <##> %@",[command GDBCommandString],[[command parseResults] description]);
	ofiBuffer = [[[[command parseResults] itemWithKey:@"value"] value] retain];
	if (![ofiBuffer isEqual:@"0"])
	{
		[_miCommand release];
		_miCommand = [[BS_MICreateOFICommand miCommand] retain];
		[_miCommand setTarget:self];
		[_miCommand setFinishAction:@selector(objectFileCreated:)];
		[(BS_MICreateOFICommand*)_miCommand setBuffer:ofiBuffer debugExtensionPath:[[self debugExtensionBundle]  executablePath]];
		
		[[[self gdbAdaptor] miController] postCommand:_miCommand];		
	}
	else
	{
		NSLog(@"OFI not allocated");
		[self didFinish];
	}
}

- (void)objectFileCreated:(id)command
{
	// ofi has been created, go for linking the module
//	NSLog(@"ofi created: %@ <##> %@",[command GDBCommandString],[[command parseResults] description]);
	NSString* result = [[[command parseResults] itemWithKey:@"value"] value];
	if ([result isEqual:@"1"])
	{
		[_miCommand release];
		_miCommand = [[BS_MILinkModuleCommand miCommand] retain];
		[_miCommand setTarget:self];
		[_miCommand setFinishAction:@selector(moduleLinked:)];
		[(BS_MILinkModuleCommand*)_miCommand setOFI: ofiBuffer moduleName:@"DebugExtension.bundle"];
		
		[[[self gdbAdaptor] miController] postCommand:_miCommand];		
	}	
	else
	{
		NSLog(@"couldn't init ofi: %@",result);
		[self didFinish];
	}
}

- (void)moduleLinked:(id)command
{
	// module has been linked, now everything is done. the inspector can take on the normal work

	//	NSLog(@"module linked: %@ <##> %@",[command GDBCommandString],[[command parseResults] description]);
	NSString* result = [[[command parseResults] itemWithKey:@"value"] value];
	if (![result isEqual:@"0"])
	{
	//	NSLog(@"module linked");
	}	
	else
	{
		NSLog(@"couldn't link module: %@",result);
	}
	[self didFinish];
}

- (void)dealloc
{
	[ofiBuffer release];
	[_miCommand release];
	[super dealloc];
}
@end
