/*
 *  DevToolsInterfaceShort.h
 *  XcodeInspectors
 *
 *  Created by Karsten Kusche on 28.02.07.
 *  Copyright 2007 __MyCompanyName__. All rights reserved.
 *
 */

// this is not a complete list of all available classes, but it's listing all that is needed in this plugin. 
// the original file has way to many classes which are not needed
#import <Cocoa/Cocoa.h>


@class PBXTSTask;
@class PBXTSPTYDeviceByteStream;
@class XCUnretainedReference;
@class PBXLSLaunchSession;
@class PBXLSTypeController;
@class PBXTSCharacterStream;
@class PBXLSAddressRange;
@class PBXTSLineBufferFilter;
@class PBXLSThread;
@class PBXBreakpoint;
@class PBXLSType;
@class PBXLSDVValue;
@class PBXLSStackFrame;
@class PBXDebugDataValueViewHelper;
@class PBXLSDynamicLinkerImage;
@class PBXTarget;
@class PBXCheapReusableSubstring;
@class PBXLSAddressValue;
@class PBXLSTypeDescription;
@class PBXLSDebuggingSession;
@class PBXLSLaunchAction;
@class PBXLSLaunchStyle;
@class PBXLSLaunchStartAction;
@class PBXLSLaunchStdioStyle;
@class PBXRuntimeSystemSpecification;
@class PBXDisassemblyFileDocument;
@class PBXProjectDocument;
@class PBXAttributedStatusView;
@class PBXExtendedOutlineView;

@protocol PBXLSViewControllerProtocol <NSObject>
- (void)dsModelDidUpdate:(id)fp8;
- (void)dsModelWillDealloc:(id)fp8;
@end

@protocol PBXTSTaskDelegate <NSObject>
- (void)task:(id)fp8 failureMessage:(id)fp12;
- (void)taskDidStart:(id)fp8;
- (void)taskDidStop:(id)fp8 stopRequested:(BOOL)fp12;
- (void)task:(id)fp8 outputData:(id)fp12;
@end

@protocol XCUnretainedReferent
- (id)unretainedReference;
@end

@protocol PBXSelectableText
- (id)selectedString;
@end

@protocol PBXFindableText <PBXSelectableText>
- (BOOL)findText:(id)fp8 ignoreCase:(BOOL)fp12 matchStyle:(int)fp16 backwards:(BOOL)fp20 wrap:(BOOL)fp24;
- (BOOL)findRegularExpression:(id)fp8 ignoreCase:(BOOL)fp12 backwards:(BOOL)fp16 wrap:(BOOL)fp20;
- (BOOL)allowsReplace;
- (BOOL)replaceCurrentSelectionWithString:(id)fp8;
- (unsigned int)replaceAllStringsMatchingString:(id)fp8 withString:(id)fp12 inSelection:(BOOL)fp16 ignoreCase:(BOOL)fp20 matchStyle:(int)fp24;
- (unsigned int)replaceAllStringsMatchingRegularExpression:(id)fp8 withString:(id)fp12 inSelection:(BOOL)fp16 ignoreCase:(BOOL)fp20;
@end

@interface PBXLSPlugin : NSObject
{
}

+ (void)pluginDidLoad:(id)fp8;
- (void)registerLaunchSystemDescriptions;

@end

@interface PBXLSDebuggingPlugin : PBXLSPlugin
{
}

- (id)init;
- (void)dealloc;
- (void)finalize;
- (BOOL)hasSharedLibraryModule;
- (id)sharedLibraryModule;
- (BOOL)hasBreakpointsModule;
- (id)breakpointsModule;
- (BOOL)hasTypeControllerModule;
- (id)typeControllerModule;
- (BOOL)isFileTypeDebuggable:(id)fp8;
- (void)registerDebuggableFileTypes;

@end

@interface PBXLSExecutableLauncher : NSObject <PBXTSTaskDelegate, XCUnretainedReferent>
{
    PBXTSTask *_task;
    PBXLSLaunchSession *_launchSession;
    NSMutableArray *_adaptors;
    PBXTSPTYDeviceByteStream *_ptyStream;
    BOOL _keepStats;
    XCUnretainedReference *_myUnretainedReference;
}

- (id)init;
- (void)dealloc;
- (void)finalize;
- (void)setKeepStats:(BOOL)fp8;
- (BOOL)keepStats;
- (void)setLaunchSession:(id)fp8;
- (id)launchSession;
- (id)executable;
- (id)launchConfig;
- (id)adaptors;
- (id)_argumentsFromAdaptors;
- (void)_updateAdaptorEnvironmentsToDictionary:(id)fp8;
- (void)cleanup;
- (id)executableArguments;
- (id)executableEnvironment;
- (id)executableDirectory;
- (id)executablePath;
- (void)taskAllocate;
- (void)taskConfigureStdIO;
- (void)taskConfigureExecutionContext;
- (void)adaptorsInstanciate;
- (void)adaptorsConfigure;
- (void)adaptorsConfigureUserInterface;
- (void)adaptorsUnconfigureUserInterface;
- (void)adaptorsExecutableDidStart;
- (void)adaptorsExecutableDidFinish;
- (void)adaptorsSetTaskIsRunning:(BOOL)fp8;
- (BOOL)launch;
- (void)stop;
- (void)userInterfaceWillBeRemoved;
- (void)task:(id)fp8 failureMessage:(id)fp12;
- (void)taskDidStart:(id)fp8;
- (void)taskDidStop:(id)fp8 stopRequested:(BOOL)fp12;
- (void)task:(id)fp8 outputData:(id)fp12;
- (id)taskArguments;
- (id)taskEnvironment;
- (id)taskDirectory;
- (id)taskPath;
- (id)task;
- (unsigned int)taskProcessID;
- (unsigned int)executableProcessID;
- (id)byteStreamFromTask;
- (id)byteStreamConsumerToTask;
- (id)byteStreamFromExecutable;
- (id)byteStreamConsumerToExecutable;
- (id)unretainedReference;

@end


@interface PBXLSExternalExecutableLauncher : PBXLSExecutableLauncher
{
}

- (id)taskArguments;
- (id)taskEnvironment;
- (id)taskDirectory;
- (id)taskPath;
- (id)externalLauncherPath;
- (id)externalLauncherArguments;
- (id)externalLauncherEnvironment;

@end

@interface PBXLSPlugableClass : NSObject
{
}

- (id)plugin;
- (Class)pluginClass;

@end

@interface PBXLSAdaptor : PBXLSPlugableClass
{
    XCUnretainedReference *_launcherReference;
    BOOL _taskIsRunning;
    NSMutableDictionary *_clientInfo;
}

+ (id)name;
+ (id)runtimeSystemSpecification;
- (id)initWithExecutableLauncher:(id)fp8;
- (void)dealloc;
- (void)finalize;
- (id)name;
- (void)updateArgumentsForLaunch:(id)fp8;
- (void)updateEnvironmentForLaunch:(id)fp8;
- (void)setExecutableLauncher:(id)fp8;
- (id)executableLauncher;
- (id)executable;
- (id)launchSession;
- (id)sessionModule;
- (void)configureAdaptor;
- (void)configureUI;
- (void)unconfigureUI;
- (void)executableDidStart;
- (void)executableDidFinish;
- (void)setTaskIsRunning:(BOOL)fp8;
- (BOOL)taskIsRunning;
- (void)dumpLog;
- (void)logString:(id)fp8;
- (void)projectDidOpen:(id)fp8;
- (void)projectWillClose:(id)fp8;
- (id)clientInfoDictionary;

@end



@interface PBXLSDebuggerAdaptor : PBXLSAdaptor <XCUnretainedReferent>
{
    NSMutableSet *_breakpointsSet;
    PBXLSTypeController *_typeController;
    unsigned int _operationNumber;
    NSMutableArray *_releasedResourceIDs;
    XCUnretainedReference *_myUnretainedReference;
}

- (id)initWithExecutableLauncher:(id)fp8;
- (void)dealloc;
- (void)finalize;
- (void)errorMessage:(id)fp8;
- (void)statusMessage:(id)fp8;
- (void)createThreadWithThreadHandle:(unsigned long)fp8 name:(id)fp12 inThreadGroupNamed:(id)fp16;
- (void)invalidateAllFramesContainerDataValue;
- (void)destroyThreadWithThreadHandle:(unsigned long)fp8;
- (id)threadGroupWithName:(id)fp8 create:(BOOL)fp12;
- (oneway void)setState:(int)fp8 status:(int)fp12 isCurrentThread:(BOOL)fp16 forServerThreadHandle:(unsigned long)fp20;
- (void)setProcessIsRunning;
- (void)willUpdateThreads;
- (void)didUpdateThreads;
- (unsigned int)operationNumber;
- (id)project;
- (id)managedBreakpointsSet;
- (id)breakpointInFile:(id)fp8 atLine:(int)fp12;
- (BOOL)supportsDebuggerActionSideImplementation;
- (id)debuggingSession;
- (id)debugSessionModule;
- (id)debuggingPlugin;
- (id)process;
- (void)setTypeController:(id)fp8;
- (id)typeController;
- (void)manageBreakpoint:(id)fp8;
- (void)stopManagingBreakpoint:(id)fp8;
- (BOOL)managesBreakpoint:(id)fp8;
- (oneway void)continueAfterInitialization;
- (BOOL)canManageBreakpoint:(id)fp8;
- (id)activeBreakpoint;
- (void)threadRequestUpdateStack:(id)fp8;
- (void)threadRequestStepInstruction:(id)fp8;
- (void)threadRequestNextInstruction:(id)fp8;
- (void)threadRequestStepInto:(id)fp8;
- (void)threadRequestStepOver:(id)fp8;
- (void)threadRequestStepOut:(id)fp8;
- (void)threadRequest:(byref id)fp8 stepUntilLineNumber:(unsigned int)fp12;
- (void)threadRequestContinue:(id)fp8;
- (void)requestDebuggerCreateWatchpoint:(id)fp8;
- (void)requestDebuggerCreateWatchpointForDataValue:(id)fp8;
- (void)requestDebuggerDeleteWatchpointForDataValue:(id)fp8;
- (oneway void)requestNewBreakpoint:(id)fp8;
- (oneway void)requestDeleteBreakpoint:(id)fp8;
- (oneway void)requestBreakpointDidChange:(id)fp8;
- (void)requestDebuggerMovePCInThread:(unsigned long)fp8 fileSpec:(id)fp12;
- (void)requestDebuggerStatus;
- (void)requestDebuggerContinueToFile:(id)fp8 lineNumber:(unsigned int)fp12;
- (void)requestDebuggerCompleteString:(id)fp8;
- (void)requestDebuggerFixAndContinue;
- (void)requestFixAndContinueFile:(id)fp8 patch:(id)fp12 object:(id)fp16 shlib:(id)fp20;
- (void)requestDisassemblyOfFrame:(id)fp8 mixedMode:(BOOL)fp12;
- (BOOL)supportsContinueToHere;
- (BOOL)supportsFixAndContinue;
- (BOOL)supportsWatchpoints;
- (oneway void)sendSIGINT;
- (oneway void)requestSuspendAllThreads;
- (id)newDataValueForFrame:(id)fp8;
- (id)newFrameContextContainerDataValue;
- (id)newGlobalContainerDataValue;
- (void)globalVariableDVAddDataValue:(id)fp8 forGlobalDict:(id)fp12;
- (void)globalVariableDVRemoveDataValueForDict:(id)fp8;
- (void)requestNewDataValueForExpression:(id)fp8 addToContainerDataValue:(id)fp12 blockStartAddress:(id)fp16;
- (void)requestNewDataValueForExpression:(id)fp8 addToContainerDataValue:(id)fp12 bindToFrame:(BOOL)fp16;
- (BOOL)canCloneDataValue:(id)fp8;
- (void)requestCloneDataValueByPathExpression:(id)fp8 addToContainerDataValue:(id)fp12;
- (void)requestCloneDataValueByContent:(id)fp8 viewAsExpression:(id)fp12 addToContainerDataValue:(id)fp16;
- (void)requestFetchGlobalsForLibrary:(id)fp8;
- (void)logMessage:(id)fp8;
- (void)requestDynamicLinkerImageControllerUpdate;
- (void)requestGlobalsBrowserUpdate;
- (void)requestMemoryBrowserUpdates;
- (void)requestLoadGlobalsInDict:(id)fp8;
- (void)requestLoadInferiorPlugin:(id)fp8;
- (void)registerIDforRelease:(id)fp8;
- (void)releaseInferiorResources;
- (id)unretainedReference;
- (id)expressionsDescriptionDV;
- (id)createNewExpressionsDescriptionDV;
- (id)globalsDescriptionDV;
- (id)registersDescriptionDVExpressionsWindow;
- (id)tooltipForBreakpoint:(id)fp8;

@end

@interface PBXLSModel : NSObject <XCUnretainedReferent>
{
    XCUnretainedReference *_debuggerReference;
    PBXLSModel *_parentModel;
    int _validityStatus;
    NSMutableArray *_children;
    int _childValidityStatus;
    NSMutableArray *_viewControllers;
    XCUnretainedReference *_unretainedReference;
}

+ (id)stringForValidityStatus:(int)fp8;
- (id)initWithDebugger:(id)fp8;
- (id)initWithDebugger:(id)fp8 parentModel:(id)fp12;
- (void)dealloc;
- (void)finalize;
- (id)_paddingForLevel:(unsigned int)fp8;
- (id)contentDescription;
- (id)contentDescriptionWithChildrenAtLevel:(unsigned int)fp8;
- (id)description;
- (id)debugger;
- (void)setValidityStatus:(int)fp8;
- (int)validityStatus;
- (void)setParentModel:(id)fp8;
- (id)parentModel;
- (void)setChildValidityStatus:(int)fp8;
- (int)childValidityStatus;
- (id)children;
- (void)addChild:(id)fp8;
- (void)insertChild:(id)fp8 atIndex:(unsigned int)fp12;
- (void)removeChild:(id)fp8;
- (void)removeChildAtIndex:(unsigned int)fp8;
- (void)removeAllChildren;
- (void)removeChildrenInRange:(struct _NSRange)fp8;
- (void)replaceChildAtIndex:(unsigned int)fp8 withChild:(id)fp12;
- (id)_viewControllers;
- (id)viewControllers;
- (void)addViewController:(id)fp8;
- (void)removeViewController:(id)fp8;
- (BOOL)haveViewControllers;
- (void)informViewControllersOfUpdate;
- (void)informViewControllersOfDealloc;
- (id)unretainedReference;

@end

@interface PBXLSDataValue : PBXLSModel
{
    NSString *_symbolicName;
    PBXLSType *_baseType;
    PBXLSType *_viewAsType;
    PBXLSType *_dynamicType;
    NSString *_typeExpression;
    NSMutableArray *_valueHistoryList;
    PBXLSDVValue *_currentValue;
    NSString *_blockStartAddress;
    int _valueChangeStatus;
    int _summaryChangeStatus;
    int _baseTypeChangeStatus;
    int _dynamicTypeChangeStatus;
    BOOL _inScope;
    BOOL _hasChildren;
    BOOL _isUpdatingAfterSet;
    int _valueFormat;
    PBXLSStackFrame *_contextFrame;
    NSString *_pathExpression;
    int _pathExpressionValidityStatus;
    PBXDebugDataValueViewHelper *_viewHelper;
    NSArray *_allChildDataValuesCache;
    SEL _expandAction;
    BOOL _isBeingWatched;
    XCUnretainedReference *_myUnretainedReference;
}

- (void)_pushNewValueAtOperationNumber:(unsigned int)fp8;
- (id)initWithDebugger:(id)fp8;
- (void)dealloc;
- (void)finalize;
- (id)contentDescription;
- (id)valueHistoryList;
- (id)parentDataValue;
- (id)containingDataValue;
- (void)setSymbolicName:(id)fp8;
- (id)symbolicName;
- (void)setBaseType:(id)fp8;
- (id)baseType;
- (void)setViewAsType:(id)fp8;
- (void)setViewHelper:(id)fp8;
- (SEL)expandAction;
- (void)setExpandAction:(SEL)fp8;
- (id)executable;
- (BOOL)isCustomizedDataDisplayEnabled;
- (id)viewHelper;
- (id)viewAsType;
- (void)setDynamicType:(id)fp8;
- (id)dynamicType;
- (id)staticType;
- (id)type;
- (void)setTypeExpressionString:(id)fp8;
- (id)typeExpressionString;
- (BOOL)isPointerType;
- (BOOL)isArrayType;
- (BOOL)canPrintDescription;
- (void)requestPrintDescriptionInThread:(id)fp8 atStackFrame:(id)fp12;
- (void)setStringValue:(id)fp8;
- (id)stringValue;
- (void)setSummary:(id)fp8;
- (id)summary;
- (void)setInScope:(BOOL)fp8;
- (BOOL)inScope;
- (BOOL)valueIsEditable;
- (void)resetValueChangeStatus;
- (void)setValueChangeStatus:(int)fp8;
- (int)valueChangeStatus;
- (void)resetSummaryChangeStatus;
- (void)setSummaryChangeStatus:(int)fp8;
- (int)summaryChangeStatus;
- (void)resetDynamicTypeChangeStatus;
- (void)setDynamicTypeChangeStatus:(int)fp8;
- (int)dynamicTypeChangeStatus;
- (void)setContextFrame:(id)fp8;
- (id)contextFrame;
- (void)recursiveClearContextFrame;
- (void)setHasChildren:(BOOL)fp8;
- (BOOL)hasChildren;
- (void)addChildDataValue:(id)fp8;
- (void)setPathExpressionString:(id)fp8;
- (id)pathExpressionString;
- (void)setPathExpressionValidityStatus:(int)fp8;
- (int)pathExpressionValidityStatus;
- (void)requestGetPathExpressionString;
- (void)requestGetPathExpressionStringForWatchpoint;
- (BOOL)canGetPathExpressionString;
- (id)allChildDataValues;
- (void)invalidateAllChildDataValuesCache;
- (void)requestUpdateValues;
- (void)requestGetChildren;
- (BOOL)canSetValueFormat;
- (void)requestSetValueFormat:(int)fp8;
- (int)valueFormat;
- (void)requestSetStringValue:(id)fp8;
- (void)requestReleaseChildren;
- (void)_informContainerViewControllersOfMyUpdate;
- (void)setUpdatingAfterSet:(BOOL)fp8;
- (BOOL)isUpdatingAfterSet;
- (void)didSetNewValue;
- (void)didUpdateValues;
- (void)didGetChildren;
- (void)didReleaseChildren;
- (id)blockStartAddress;
- (void)setBlockStartAddress:(id)fp8;
- (BOOL)isBeingWatched;
- (void)setIsBeingWatched:(BOOL)fp8;
- (id)unretainedReference;

@end

@interface PBXLSDynamicLinkerImage : PBXLSModel
{
    NSString *_sharedLibraryPath;
    NSString *_name;
    PBXLSAddressRange *_addressRange;
    int _symbolsStatus;
    int _symbolsLevel;
    int _symbolsLoadTime;
    int _sharedLibraryStatus;
    NSMutableArray *_globalVariables;
}

+ (id)_myBundle;
+ (id)stringForSharedLibraryStatus:(int)fp8;
+ (id)symbolLevelArray;
+ (id)stringForSymbolsLevel:(int)fp8;
+ (id)stringForSymbolsLoadTime:(int)fp8;
+ (id)nameFromPath:(id)fp8;
+ (id)systemSharedLibraryNameRegEx;
- (id)init;
- (void)dealloc;
- (void)finalize;
- (id)description;
- (id)contentDescription;
- (void)setEqualTo:(id)fp8;
- (id)dynamicLinkerImageController;
- (void)setSharedLibraryPath:(id)fp8;
- (id)sharedLibraryPath;
- (id)displayName;
- (id)name;
- (void)setName:(id)fp8;
- (BOOL)isSystemSharedLibrary;
- (void)setSymbolsStatus:(int)fp8;
- (int)symbolsStatus;
- (void)setSymbolsLevel:(int)fp8;
- (int)symbolsLevel;
- (void)setSymbolsLoadTime:(int)fp8;
- (int)symbolsLoadTime;
- (void)setSharedLibraryStatus:(int)fp8;
- (int)sharedLibraryStatus;
- (void)setAddressRange:(id)fp8;
- (id)addressRange;
- (int)compareByName:(id)fp8;
- (int)compareByAddress:(id)fp8;
- (int)compareBySymbolsLevel:(id)fp8;
- (int)compareBySymbolsWhenToLoad:(id)fp8;
- (void)requestUpdateSymbolsToLevel:(int)fp8;
- (void)didUpdateSymbolsToLevel;
- (void)setGlobalVariables:(id)fp8;
- (id)globalVariables;

@end
@interface PBXLSType : NSObject
{
    PBXLSTypeController *_typeController;
    NSString *_expressionString;
    PBXLSTypeDescription *_typeDescription;
    BOOL _canBeDynamic;
}

- (id)init;
- (void)dealloc;
- (void)finalize;
- (id)description;
- (void)setTypeController:(id)fp8;
- (id)typeController;
- (void)setExpressionString:(id)fp8;
- (id)expressionString;
- (BOOL)isBOOLOrBooleanType;
- (void)setTypeDescription:(id)fp8;
- (id)typeDescription;
- (unsigned int)hash;
- (BOOL)isEqual:(id)fp8;
- (void)setCanBeDynamic:(BOOL)fp8;
- (BOOL)canBeDynamic;

@end

@interface PBXLSTypeController : NSObject
{
    PBXLSDebuggingSession *_debuggingSession;
}

+ (id)typeControllerForSession:(id)fp8;
- (void)dealloc;
- (void)finalize;
- (void)setDebuggingSession:(id)fp8;
- (id)debuggingSession;
- (id)typeByExpressionString:(id)fp8;

@end

@interface PBXLSLaunchConfig : PBXLSPlugableClass
{
    NSString *_identifier;
    PBXLSLaunchAction *_launchAction;
    NSString *_displayName;
    NSArray *_requiredAdaptorNames;
    NSArray *_additionalAdaptorNames;
    NSArray *_allowableLaunchStyles;
    PBXLSLaunchStyle *_launchStyle;
    NSArray *_allowableLaunchStartActions;
    PBXLSLaunchStartAction *_launchStartAction;
    NSArray *_allowableLaunchStdioStyles;
    PBXLSLaunchStdioStyle *_launchStdioStyle;
    NSString *_remoteHostInfo;
    NSString *_startActionInfo;
    NSArray *_fileTypes;
    PBXRuntimeSystemSpecification *_rtsSpec;
    NSString *_pid;
    NSString *_coreFile;
    PBXLSLaunchStartAction *_previousLaunchStartAction;
}

+ (id)config;
+ (id)launchConfigFromDictionary:(id)fp8;
+ (unsigned int)updateLaunchConfigs:(id)fp8 fromDictionary:(id)fp12;
- (id)init;
- (void)dealloc;
- (void)finalize;
- (BOOL)supportsSymbolLevels;
- (id)copyWithZone:(struct _NSZone *)fp8;
- (id)description;
- (void)setLaunchAction:(id)fp8;
- (id)launchAction;
- (void)setDisplayName:(id)fp8;
- (id)displayName;
- (void)setIdentifier:(id)fp8;
- (id)identifier;
- (id)newExecutableLauncher;
- (id)adaptorNames;
- (void)setRequiredAdaptorNames:(id)fp8;
- (id)requiredAdaptorNames;
- (void)setAdditionalAdaptorNames:(id)fp8;
- (id)additionalAdaptorNames;
- (id)_validateValue:(id)fp8 inAllowableValues:(id)fp12;
- (void)setAllowableLaunchStyles:(id)fp8;
- (id)allowableLaunchStyles;
- (void)setLaunchStyle:(id)fp8;
- (id)launchStyle;
- (BOOL)allowsRemoteLaunching;
- (id)validateLaunchStyle:(id)fp8;
- (void)setAllowableLaunchStartActions:(id)fp8;
- (id)allowableLaunchStartActions;
- (void)setLaunchStartAction:(id)fp8;
- (void)setTemporaryLaunchStartAction:(id)fp8;
- (id)launchStartAction;
- (id)validateLaunchStartAction:(id)fp8;
- (BOOL)mustLaunchExecutableImmediately;
- (void)setAllowableLaunchStdioStyles:(id)fp8;
- (id)allowableLaunchStdioStyles;
- (void)setLaunchStdioStyle:(id)fp8;
- (id)launchStdioStyle;
- (id)validateLaunchStdioStyle:(id)fp8;
- (void)setRemoteHostInfo:(id)fp8;
- (id)remoteHostInfo;
- (void)setStartActionInfo:(id)fp8;
- (id)startActionInfo;
- (void)setExecutableFileTypes:(id)fp8;
- (id)executableFileTypes;
- (void)setPrimaryRuntimeSystemSpecification:(id)fp8;
- (id)primaryRuntimeSystemSpecification;
- (id)encodeState;
- (void)decodeState:(id)fp8;
- (id)pid;
- (void)setPid:(id)fp8;
- (id)coreFile;
- (void)setCoreFile:(id)fp8;
- (void)resetTemporaryLaunchStartAction;

@end

@interface PBXModule : NSWindowController
{
    PBXModule *_supermodule;
    NSMutableArray *_submodules;
    NSView *_view;
    id _delegate;
    NSString *_label;
    struct _NSMapTable *_actionCache;
    struct {
        unsigned int viewLoaded:1;
        unsigned int viewIsLoading:1;
        unsigned int needsUpdate:1;
        unsigned int viewIsInstalled:1;
        unsigned int wantsOwnWindow:1;
        unsigned int ignoreForwarding:1;
        unsigned int RESERVED:26;
    } _mFlags;
}

+ (void)initialize;
+ (id)defaultModuleNibName;
- (id)initWithModuleNibName:(id)fp8;
- (id)initWithModuleNibPath:(id)fp8;
- (id)initWithWindowNibName:(id)fp8;
- (id)initWithWindowNibName:(id)fp8 owner:(id)fp12;
- (id)initWithWindowNibPath:(id)fp8 owner:(id)fp12;
- (id)init;
- (void)dealloc;
- (void)finalize;
- (void)setDelegate:(id)fp8;
- (id)delegate;
- (id)moduleNibName;
- (id)moduleNibPath;
- (id)windowNibName;
- (id)windowNibPath;
- (id)slideOutTabIconImage;
- (id)identifier;
- (BOOL)isViewLoaded;
- (id)view;
- (void)setView:(id)fp8;
- (void)windowDidLoad;
- (BOOL)loadView;
- (void)loadWindow;
- (void)viewWillLoad;
- (void)viewDidLoad;
- (void)_viewWillLoad;
- (void)_doPendingConfiguration;
- (void)_viewDidLoad;
- (void)awakeFromNib;
- (void)_moduleViewWasInstalled:(id)fp8;
- (void)moduleViewWasInstalled:(id)fp8;
- (void)_moduleViewWillBeRemoved:(id)fp8;
- (void)moduleViewWillBeRemoved:(id)fp8;
- (BOOL)isViewInstalled;
- (void)viewWasInstalled;
- (void)viewWillBeRemoved;
- (BOOL)moduleShouldClose;
- (void)addNotificationObservers;
- (void)removeNotificationObservers;
- (void)_removeNotificationObservers;
- (void)recursivelyRemoveNotificationObservers;
- (void)recursivelyAddNotificationObservers;
- (id)firstKeyView;
- (id)lastKeyView;
- (void)setLabel:(id)fp8 representedFilename:(id)fp12;
- (void)setLabel:(id)fp8;
- (void)setLabelAsFilename:(id)fp8;
- (id)label;
- (id)representedFilename;
- (void)moduleDidChangeLabel:(id)fp8;
- (id)windowController;
- (BOOL)isActive;
- (BOOL)isVisible;
- (void)showModule:(id)fp8;
- (void)hideModule:(id)fp8;
- (void)hide;
- (void)moduleWillBeHidden;
- (void)moduleWasDisplayed;
- (void)moduleWasExposedByUser;
- (void)moduleWasHiddenByUser;
- (void)showWindow:(id)fp8;
- (void)showHelp:(id)fp8;
- (BOOL)needsUpdate;
- (void)_informWindowControllerOfUpdateStatus;
- (void)setNeedsUpdate:(BOOL)fp8;
- (void)noteNeedsUpdate:(id)fp8;
- (void)update;
- (void)updateIfNeeded;
- (void)updateRecursivelyIfNeeded;
- (id)supermodule;
- (void)setSupermodule:(id)fp8;
- (id)submodules;
- (void)_module:(id)fp8 didAddSubmodule:(id)fp12;
- (void)module:(id)fp8 didAddSubmodule:(id)fp12;
- (void)_module:(id)fp8 willRemoveSubmodule:(id)fp12;
- (void)module:(id)fp8 willRemoveSubmodule:(id)fp12;
- (void)insertSubmodule:(id)fp8 atIndex:(unsigned int)fp12;
- (void)addSubmodule:(id)fp8;
- (void)removeSubmodule:(id)fp8;
- (BOOL)isAncestorOfModule:(id)fp8;
- (id)supermoduleOfType:(Class)fp8;
- (id)firstSubmoduleOfType:(Class)fp8;
- (id)mainEditor;
- (BOOL)acceptsFirstResponder;
- (id)moduleToolbarAllowedItemIdentifiers;
- (id)moduleToolbarDefaultItemIdentifiers;
- (id)moduleToolbar:(id)fp8 itemForItemIdentifier:(id)fp12 willBeInsertedIntoToolbar:(BOOL)fp16;
- (id)moduleToolbarIdentifier;
- (void)configureToolbarOnWindow:(id)fp8;
- (id)toolbar:(id)fp8 itemForItemIdentifier:(id)fp12 willBeInsertedIntoToolbar:(BOOL)fp16;
- (id)toolbarCombinableItemIdentifiers:(id)fp8;
- (id)toolbarAllowedItemIdentifiers:(id)fp8;
- (id)toolbarDefaultItemIdentifiers:(id)fp8;
- (void)toolbarDidRemoveItem:(id)fp8;
- (void)toolbarWillAddItem:(id)fp8;
- (struct _NSMapTable *)actionCache;
- (void)clearActionCache;
- (id)targetModules;
- (id)localModuleActions;
- (id)targetModuleActions;
- (id)allModuleActions;
- (id)moduleForAction:(SEL)fp8;
- (BOOL)validateMenuItem:(id)fp8;
- (BOOL)validateLocalMenuItem:(id)fp8;
- (BOOL)respondsToSelector:(SEL)fp8;
- (void)forwardInvocation:(id)fp8;
- (id)methodSignatureForSelector:(SEL)fp8;
- (struct _NSSize)viewMinSize;
- (struct _NSSize)viewMaxSize;
- (BOOL)moduleEnforcesViewMinSize;
- (void)setWantsModuleWindow:(BOOL)fp8;
- (BOOL)wantsModuleWindow;
- (id)loadModuleWindow;
- (BOOL)isDocumentModule;
- (BOOL)isMainModule;
- (Class)moduleWindowClass;
- (unsigned int)moduleWindowStyleMask;
- (id)moduleWindowFrameAutosaveName;
- (id)configurationIdentifier;
- (id)geometryConfigurationDictionary;
- (void)takeGeometryConfigurationFromDictionary:(id)fp8;
- (id)contentConfigurationDictionary;
- (void)takeContentConfigurationFromDictionary:(id)fp8;
- (void)saveUserDefaultConfiguration;
- (void)windowWillShow;
- (void)windowDidShow;
- (id)keyTabView;
- (id)dockMenuItems;
- (BOOL)canCloseInDock;
- (BOOL)canCloneInDock;
- (id)cloneInDock;
- (BOOL)canRename;

@end

@interface PBXProjectModule : PBXModule <PBXFindableText>
{
    PBXProjectDocument *_projectDocument;
    BOOL _readingGeomtry;
    PBXAttributedStatusView *_statusBar;
    BOOL _statusBarInitiallyHidden;
    PBXProjectModule *_initialActiveModule;
    NSString *_guid;
    id _sharingToken;
}

+ (void)initialize;
+ (id)lastActiveType:(Class)fp8 inContextOfModule:(id)fp12 lookBeyondContext:(BOOL)fp16;
+ (id)lastActiveType:(Class)fp8 inContextOfModule:(id)fp12 matchingFunction:(void)fp16 usingData:(void *)fp17 lookBeyondContext:(BOOL)fp21;
+ (id)lastActiveType:(Class)fp8 forWindow:(id)fp12;
+ (id)lastActiveType:(Class)fp8 forWindow:(id)fp12 orProjectDocument:(id)fp16;
+ (id)lastActiveForWindow:(id)fp8;
+ (BOOL)hasType:(Class)fp8 forWindow:(id)fp12;
+ (void)removeTypesFromWindow:(id)fp8;
+ (void)dumpAllTypes;
- (void)dealloc;
- (void)finalize;
- (id)projectDocument;
- (void)setProjectDocument:(id)fp8;
- (id)project;
- (id)workspace;
- (void)_sendProjectDocumentWillChange:(id)fp8 toChildrenOfModule:(id)fp12;
- (void)projectDocumentWillChange:(id)fp8;
- (id)moduleForAction:(SEL)fp8;
- (BOOL)moduleShouldClose;
- (id)loadModuleWindow;
- (BOOL)windowShouldClose:(id)fp8;
- (void)windowWillClose:(id)fp8;
- (id)geometryConfigurationDictionary;
- (void)takeGeometryConfigurationFromDictionary:(id)fp8;
- (id)sharingToken;
- (void)setSharingToken:(id)fp8;
- (void)_perspectiveWillChange:(id)fp8;
- (void)_perspectiveDidDisplay:(id)fp8;
- (id)contentConfigurationDictionary;
- (void)takeContentConfigurationFromDictionary:(id)fp8 forSharingKey:(id)fp12;
- (void)takeContentConfigurationFromDictionary:(id)fp8;
- (Class)moduleWindowClass;
- (id)statusBar;
- (void)addNotificationObservers;
- (void)setInitialActiveModule:(id)fp8;
- (id)initialActiveModule;
- (void)windowDidShow;
- (id)firstKeyView;
- (id)lastKeyView;
- (id)keyModules;
- (void)gotoNextActiveModule;
- (void)gotoPreviousActiveModule;
- (id)createToolbarItemWithIdentifier:(id)fp8 proxiedToToolbar:(id)fp12;
- (BOOL)canCloneInDock;
- (id)cloneInDock;
- (void)_viewDidLoad;
- (void)showModule:(id)fp8;
- (void)configureSplittersOnScrollView:(id)fp8;
- (void)_splitEditorVertically:(id)fp8;
- (void)_closeEditorVertically:(id)fp8;
- (id)mainEditor;
- (id)selectedString;
- (BOOL)findText:(id)fp8 ignoreCase:(BOOL)fp12 matchStyle:(int)fp16 backwards:(BOOL)fp20 wrap:(BOOL)fp24;
- (BOOL)findRegularExpression:(id)fp8 ignoreCase:(BOOL)fp12 backwards:(BOOL)fp16 wrap:(BOOL)fp20;
- (BOOL)allowsReplace;
- (BOOL)replaceCurrentSelectionWithString:(id)fp8;
- (unsigned int)replaceAllStringsMatchingString:(id)fp8 withString:(id)fp12 inSelection:(BOOL)fp16 ignoreCase:(BOOL)fp20 matchStyle:(int)fp24;
- (unsigned int)replaceAllStringsMatchingRegularExpression:(id)fp8 withString:(id)fp12 inSelection:(BOOL)fp16 ignoreCase:(BOOL)fp20;
- (id)_windowDelegate;
- (void)markAsLastActive;
- (void)removeFromLastActiveList;
- (BOOL)isActivationCandidate;
- (BOOL)isDisplayCandidate;
- (void)_removeNotificationObservers;
- (id)guid;
- (void)populateGuidArray:(id)fp8;
- (void)populateServicesArray:(id)fp8;
- (void)_setGuid:(id)fp8;
- (id)containingPerspectiveIdentifier;
- (id)lastActiveType:(Class)fp8;
- (id)lastActiveType:(Class)fp8 matchingFunction:(void)fp12 usingData:(void *)fp13;

@end



@interface PBXDebugViewModule : PBXProjectModule
{
    BOOL _removeOnWindowClose;
}

+ (id)attributeDictionaryForColor:(id)fp8;
+ (id)attributeDictionaryForBackgroundColor:(id)fp8;
+ (id)stringFromString:(id)fp8 withAttributes:(id)fp12;
+ (void)_addAttributes:(id)fp8 forAttributeKey:(id)fp12 toAttributedString:(id)fp16;
+ (id)stringInRedColorFromString:(id)fp8;
+ (id)stringInBlackColorFromString:(id)fp8;
+ (id)stringInRedBackgroundColorFromString:(id)fp8;
+ (id)stringInGrayColorFromString:(id)fp8;
- (id)sessionModule;
- (void)dealloc;
- (void)finalize;
- (void)installViewFromModule:(id)fp8 inView:(id)fp12;
- (void)debugViewModuleWindowWillClose:(id)fp8;
- (void)_setupNotificationForWindowWillClose:(id)fp8;
- (void)setRemoveSelfFromSessionOnWindowClose;
- (void)viewWasInstalled;
- (void)validateToolbarButtons;

@end
@interface PBXDebugDSModelViewModule : PBXDebugViewModule <PBXLSViewControllerProtocol>
{
    PBXLSModel *_model;
    PBXDebugViewModule *_selectedSubModelViewModule;
}

- (void)setModel:(id)fp8;
- (id)model;
- (void)setSelectedSubModelViewModule:(id)fp8;
- (id)selectedSubModelViewModule;
- (void)dsModelDidUpdate:(id)fp8;
- (void)dsModelWillDealloc:(id)fp8;
- (void)updateUI;

@end
@interface PBXDebugDataValueViewModule : PBXDebugDSModelViewModule
{
    PBXExtendedOutlineView *_variablesView;
    NSTableColumn *_typeColumn;
    NSTableColumn *_summaryColumn;
    NSScrollView *_scrollView;
    PBXLSDataValue *_containerDV;
    int _containerChildCount;
    NSTextField *_viewAsSheetValueTextField;
    NSTextField *_viewAsSheetTypeExpressionTextField;
    NSPanel *_viewAsSheet;
    PBXLSDataValue *_pendingDVForGettingPathExpression;
    NSMutableSet *_pendingDVsForSettingFormatSet;
    NSMutableArray *_childrenToExpand;
    PBXLSDataValue *_editedDV;
    NSMutableArray *_lastVisibleDataItems;
    struct _NSRange _lastVisibleDataItemsRange;
    BOOL _isRestoringSavedPosition;
    int _pendingAutoexpandCount;
    NSTimer *_clearLastVisibleItemsTimer;
    PBXLSDataValue *_pendingDVPathForViewAsMemory;
    NSImage *_spyglassImage;
}

+ (void)initialize;
+ (id)VarNameColumnIdentifier;
+ (id)VarValueColumnIdentifier;
+ (id)VarTypeColumnIdentifier;
+ (id)VarSummaryColumnIdentifier;
- (void)dealloc;
- (void)finalize;
- (id)variablesView;
- (id)_pendingDVsForSettingFormatSet;
- (void)viewWasInstalled;
- (void)viewDidLoad;
- (void)setNameColumnTitle:(id)fp8;
- (id)selectedDataValues;
- (id)localModuleActions;
- (BOOL)validateLocalMenuItem:(id)fp8;
- (void)debugDataMenuPrintDescriptionAction:(id)fp8;
- (BOOL)showingTypes;
- (void)showTypes:(BOOL)fp8;
- (void)debugDataMenuToggleShowTypes:(id)fp8;
- (void)debugDataMenuCloneVariableByExpression:(id)fp8;
- (void)viewVariableValueHistory:(id)fp8;
- (void)debugDataMenuViewAsMemory:(id)fp8;
- (void)debugDataMenuCreateWatchpoint:(id)fp8;
- (void)debugDataMenuShowVariableAsExpressionAction:(id)fp8;
- (void)debugDataMenuEditValueAction:(id)fp8;
- (void)debugDataMenuEditSummaryAction:(id)fp8;
- (void)_viewAsSheetDidEnd:(id)fp8 returnCode:(int)fp12 contextInfo:(void *)fp16;
- (void)debugDataMenuViewContentsAsInNewWindow:(id)fp8;
- (void)viewAsSheetTypeExpressionTextFieldDidEndEditing:(id)fp8;
- (void)viewAsSheetCancelButtonPressed:(id)fp8;
- (void)viewAsSheetOKButtonPressed:(id)fp8;
- (void)doubleClickAction:(id)fp8;
- (void)debugDataMenuSetValueFormatAction:(id)fp8;
- (void)cancelRestoreSavedPosition:(id)fp8;
- (void)restoreSavedPosition:(id)fp8;
- (void)setContainerDV:(id)fp8;
- (id)dataValueForWatchpointExpression:(id)fp8;
- (void)setWatching:(BOOL)fp8 dataValue:(id)fp12;
- (id)containerDV;
- (void)setModel:(id)fp8;
- (void)dsModelDidUpdate:(id)fp8;
- (void)updateUI;
- (void)autoExpandChildren:(id)fp8;
- (void)refreshDisplay;
- (void)updateFromContainerDataValue;
- (void)updateDataValue:(id)fp8;
- (BOOL)outlineView:(id)fp8 shouldExpandItem:(id)fp12;
- (void)outlineView:(id)fp8 willDisplayCell:(id)fp12 forTableColumn:(id)fp16 item:(id)fp20;
- (int)outlineView:(id)fp8 numberOfChildrenOfItem:(id)fp12;
- (id)outlineView:(id)fp8 child:(int)fp12 ofItem:(id)fp16;
- (id)outlineView:(id)fp8 objectValueForTableColumn:(id)fp12 byItem:(id)fp16;
- (id)outlineView:(id)fp8 toolTipForCell:(id)fp12 rect:(struct _NSRect *)fp16 tableColumn:(id)fp20 item:(id)fp24 mouseLocation:(struct _NSPoint)fp28;
- (BOOL)outlineView:(id)fp8 isItemExpandable:(id)fp12;
- (void)outlineViewItemDidExpand:(id)fp8;
- (void)outlineViewItemDidCollapse:(id)fp8;
- (BOOL)outlineView:(id)fp8 shouldEditTableColumn:(id)fp12 item:(id)fp16;
- (void)outlineView:(id)fp8 setObjectValue:(id)fp12 forTableColumn:(id)fp16 byItem:(id)fp20;

@end
@interface PBXDebugStackFrameViewModule : PBXDebugDataValueViewModule
{
}

- (void)dealloc;
- (void)finalize;
- (id)moduleNibName;
- (void)setModel:(id)fp8;
- (id)stackFrame;
- (int)currentLineNumber;
- (void)dsModelDidUpdate:(id)fp8;
- (void)updateUI;
- (void)updateFromContainerDataValue;
- (id)geometryConfigurationDictionary;
- (void)takeGeometryConfigurationFromDictionary:(id)fp8;

@end
