//
//  NSObjectExt.m
//  XcodeInspectors
//
//  Created by Karsten Kusche on 03.02.07.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#import "NSObjectExt.h"
#import <objc/objc.h>
#import <objc/objc-class.h>
#import "BSDebugObject.h"

BSDebugDataStructure* _NSDataForDebugger(NSObject* object)
{
	// this method is the c-wrapper for [object debugData]
	// it is called from gdb
	return [object debugData];
}


@implementation NSObject (BSDebugExtension)

+ (Class)debuggerObjectClass
{
	// this class is used to represent every object
	return [BSDebugObject class];
}

- (Class)debuggerObjectClass
{
	// this stuff is class-based so ask the class
	return [[self class] debuggerObjectClass];
}

+(BSDebugDataStructure*)debugDataFrom:(id)object
{
	// this method creates a debug-object and encodes it, then writes it into some memory
	// and provides a BSDebugDataStructure with size and pointer of that memory
	BSDebugObject* debugObject = [BSDebugObject debugObjectWith:object];

	NSMutableData *data = [NSMutableData data];
	NSKeyedArchiver* archiver = [[NSKeyedArchiver alloc] initForWritingWithMutableData:data]; 
	[archiver encodeObject:debugObject forKey:@"debugObject"];
	[archiver finishEncoding];
	[archiver release];
	[debugObject release];
	
	BSDebugDataStructure* ds = nil;
	if (data)
	{
		//NSLog(@"data is present:\n %@",data);
		ds = (BSDebugDataStructure*)malloc(sizeof(BSDebugDataStructure));
		ds->size = [data length];
		ds->data = (void*)malloc(ds->size);
		[data getBytes:ds->data];
		[data release];
		//NSLog(@"data is at: %p with %i bytes",ds->data,ds->size);
	}	
	else
	{
		//NSLog(@"data is nil");
	}
	return ds;
}

+(BSDebugDataStructure*)debugData
{
	// return the debug data for this class
	return [self debugDataFrom:self];
}

-(BSDebugDataStructure*)debugData
{
	// return the debug data of this object, but use the class's implementation
	return [[self class] debugDataFrom:self];
}

- (NSString*)shortDescription
{
	// just some short string for each object like <ClassName 0x4245>
	return [NSString stringWithFormat:@"<%@ %p",[self className],self];
}

+ (NSString*)shortDescription
{
	// returns just the ClassName
	return [NSString stringWithFormat:@"a %@ class",[self description]];
}

@end

@implementation NSString (BSDebugExtension)

- (NSString*)shortDescription
{
	//strings should be supplied how they are, but shorter
	if ([self length] > 20)
	{
		return [self substringToIndex:20];
	}
	return self;
}

@end
